# dynamo_db_resource

This package is an abstraction for Dynamo DB of the boto3 package from AWS for the usage with the AWS Serverless Wrapper.
It currently relies on the config of the wrapper to work.
